#include <Arduino.h>
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#include "TeaTimer.hpp"
#include "SmartServo.hpp"

#define WIRE Wire

#define DISPLAY_PIN 4   // D2 (SDA)
#define SERVO_PIN 2     // D4
#define TOUCH_BTN_PIN 0 // D3

auto display = Adafruit_SSD1306(128, 32, &WIRE);

SmartServo smartServo(SERVO_PIN);
TeaTimer teaTimer;

void setup()
{
  // Serial.begin(9600);

  teaTimer.init(&smartServo);

  pinMode(LED_BUILTIN, OUTPUT);
  pinMode(TOUCH_BTN_PIN, INPUT);

  display.begin(SSD1306_SWITCHCAPVCC, 0x3C); // Address 0x3C for 128x32
  // Show image buffer on the display hardware.
  // Since the buffer is intialized with an Adafruit splashscreen
  // internally, this will display the splashscreen.
  display.display();
  delay(1000);

  smartServo.moveServoToZero();
}

void printMsg(const String &s)
{
  display.clearDisplay();
  display.setTextColor(WHITE);
  display.setTextSize(2);
  display.setCursor(0, 10);
  display.println(s);
  display.display();
}
void printMsg(unsigned long l)
{
  display.clearDisplay();
  display.setTextColor(WHITE);
  display.setTextSize(2);
  display.setCursor(0, 10);
  display.println(l);
  display.display();
}

bool isBtnPressed()
{
  if (millis() < 10000) return false;
  return digitalRead(TOUCH_BTN_PIN) == HIGH;
}
void loop()
{
  teaTimer.tick();

  if (isBtnPressed())
  {
    printMsg("BUTTON");
    teaTimer.beginSteeping(5000);
  }
  else if (!teaTimer.isSteeping())
  {
    printMsg("Default");
  }
  else
  {
    auto r = teaTimer.remainingSteepTimeSeconds();
    printMsg(r);
  }
}

void toggle_led()
{
  digitalWrite(LED_BUILTIN, !digitalRead(LED_BUILTIN));
}